@@ -72,11 +72,7 @@ def remove_punctuation(text):
     """
 
     text = " ".join(
-        [
-            word
-            for word in word_tokenize(text)
-            if word not in (string.punctuation)
-        ]
+        [word for word in word_tokenize(text) if word not in (string.punctuation)]
     )
     return text
 
@@ -161,7 +157,7 @@ def correct_grammar(text):
     return text
 
 
-def remove_stopwrods(text):
+def remove_stopwords(text):
     """A method to remove stopwords from text
 
     Args:
@@ -172,9 +168,7 @@ def remove_stopwrods(text):
     """
 
     stop = stopwords.words("english")
-    text = " ".join(
-        [word for word in word_tokenize(text) if word not in (stop)]
-    )
+    text = " ".join([word for word in word_tokenize(text) if word not in (stop)])
     return text
 
 
@@ -204,9 +198,7 @@ def apply_lammatization(text):
     """
 
     lemmatizer = WordNetLemmatizer()
-    text = " ".join(
-        [lemmatizer.lemmatize(word) for word in word_tokenize(text)]
-    )
+    text = " ".join([lemmatizer.lemmatize(word) for word in word_tokenize(text)])
     return text
 
 
